@@ -55,14 +55,13 @@ class StatusHistoryExec(object):
         if sessionId is not None:
             self.__reqObj.setValue("sessionid", sessionId)
 
-        self.__sessionId = self.__reqObj.getSessionId()
-        self.__sessionObj = self.__reqObj.newSessionObj()
-        self.__sessionPath = self.__sessionObj.getPath()
+        # retained due to side effects
+        _sessionObj = self.__reqObj.newSessionObj()  # noqa: F841
         self.__reqObj.printIt(ofh=self.__lfh)
         #
 
     def doCreateStatusHistory(self, numProc=1, overWrite=False):
-        """"""
+        """ """
         try:
             shu = StatusHistoryUtils(reqObj=self.__reqObj, verbose=self.__verbose, log=self.__lfh)
             entryIdList = shu.getEntryIdList()
@@ -75,7 +74,7 @@ class StatusHistoryExec(object):
             traceback.print_exc(file=self.__lfh)
 
     def doLoadStatusHistory(self, numProc=1, newTable=False):
-        """"""
+        """ """
         try:
             shu = StatusHistoryUtils(reqObj=self.__reqObj, verbose=self.__verbose, log=self.__lfh)
             if numProc > 1:
@@ -97,7 +96,7 @@ class StatusHistoryExec(object):
         return False
 
     def doCreateEntryStatusHistory(self, entryId, overWrite=False):
-        """"""
+        """ """
         try:
             shu = StatusHistoryUtils(reqObj=self.__reqObj, verbose=self.__verbose, log=self.__lfh)
             rL = shu.createHistory([entryId], overWrite=overWrite)
